A PrepRecipe is Recipe with the results corresponding to the steps defined in the Recipe.
Usage
prep_recipe(rec, results, bakes, execution = list())A PrepRecipe is Recipe with the results corresponding to the steps defined in the Recipe.
prep_recipe(rec, results, bakes, execution = list())