A Recipe is a description of the steps to be applied to a data set in order to prepare it for data analysis.
Slots
phyloseqPhyloseq-class object.
var_infoDeprecated compatibility storage synchronized from
model$targetsfor modeled recipes.tax_infoDeprecated compatibility storage synchronized from
model$tax_levelfor modeled recipes.stepsList of step-class objects that will be used by DA.
modelOptional centralized statistical model specification created by
add_model().